package com.ssm.manage.mapper;

import com.ssm.manage.extendEntity.MemberStatistic;
import com.ssm.manage.extendEntity.ProjectLists;
import com.ssm.manage.extendEntity.ProjectStatistic;
import com.ssm.manage.query.AccountTradeRecordRequest;
import com.ssm.manage.query.CourseAccountRequest;
import com.ssm.manage.query.ProjectListsRequest;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@Component
public interface StoreStatisticMapper {
    List<MemberStatistic> selectMemberList(AccountTradeRecordRequest accountTradeRecordRequest);

    List<ProjectStatistic> selectProjectList(AccountTradeRecordRequest accountTradeRecordRequest);
    List<ProjectStatistic> selectProjectLists(AccountTradeRecordRequest accountTradeRecordRequest);
    //按月份和门店统计项目购买金额和次数
    List<ProjectLists> selectProjectLists1(ProjectListsRequest projectListsRequest);
    //按门店统计项目结存金额和次数
    List<ProjectLists> selectProjectLists2(@Param("storeId") Long storeId, @Param("allowValid")String allowValid);
    //按月份和门店统计项目服务金额和次数
    List<ProjectLists> selectProjectLists3(ProjectListsRequest projectListsRequest);

}
